# Emby Python Client

A Python client for Emby Media Server's API. 

**NOTE**: The [original source code](https://github.com/MediaBrowser/Emby.SDK/tree/master/SampleCode/RestApi/Clients/Python) for this client is auto-generated by Emby's OpenAPI spec.
This specific client is an automated release of the source code with some minor modifications.
Any bugs or issues with the client should be reported to the [Emby SDK repository](https://github.com/MediaBrowser/Emby.SDK)

## Python Version Support

Python 2.7 (deprecated) or 3.4+

## Installation

Install via [pip](https://pypi.org/project/embyclient/):

```sh
pip install embyclient
```

## Usage

Import the package:

```python
import embyclient
```

Configure a client instance:

```python
import embyclient
from embyclient.rest import ApiException

# Configure API key authorization: apikeyauth
configuration = embyclient.Configuration()
configuration.api_key['api_key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api_key'] = 'Bearer'

# create an instance of the API class
client = embyclient.ApiClient(configuration)
```

Then use the client to interact via specific API services:

```python
activity_log_service = embyclient.ActivityLogServiceApi(client)

try:
    # Gets activity log entries
    api_response = activity_log_service.get_activity_log_entries(start_index=56, limit=56, min_date='min_date_example')
    print(api_response)
except ApiException as e:
    print("Exception when calling ActivityLogServiceApi->get_activity_log_entries: %s\n" % e)
```

## Documentation

For more information, please visit [Emby's API documentation](https://swagger.emby.media/?staticview=true).
